main.get_elec_cooling_data — DarkHistory documentation

# main.get_elec_cooling_data

`main.` `get_elec_cooling_data`(eleceng, photeng)

  Returns electron cooling data for use in `main.evolve()`.

  Parameters: | eleceng : ndarray The electron energy abscissa. photeng : ndarray The photon energy abscissa.
  Returns: | tuple of ndarray A tuple with containing 3 tuples. The first tuple contains the normalized collisional ionization scattered electron spectrum for HI, HeI and HeII. The second contains the normalized collisional excitation scattered electron spectrum for HI, HeI and HeII. The last tuple is an `EnglossRebinData` object for use in rebinning ICS energy loss data to obtain the ICS scattered electron spectrum.

#### Previous topic

main.evolve

#### Next topic

main.get_tf

### This Page

Show Source